==> jmb.organization-0.2.7.tar.gz: jmb.organization-0.2.7/jmb/organization/settings.py <==
# -*- coding: utf-8 -*-
from django.utils.translation import ugettext_lazy as _

#: Configurazione dell'unicità dell'Organization
ORGANIZATION_ORGANIZATION_UNIQUE_TOGETHER = (
#    FIXME
#    ("vat_number", "ssn", "organization_type__category"),
    ("vat_number", "ssn", "organization_type"),
)

#: Configurazione dello stile dei campi - stile: 'title', 'upper', 'lower'
ORGANIZATION_ORGANIZATION_NAME_STYLE = 'title'
ORGANIZATION_CONTACT_NAME_STYLE = 'title'

#: Configurazione path foto dei contatti
ORGANIZATION_CONTACT_UPLOAD_PHOTO = "contact_photo"

#: Configurazione choices
ORGANIZATION_ORGANIZATIONTYPE_DEF = (
    ("com", _("owner company"),),
    ("cus", _("customer"),),
    ("sup", _("supplier"),),
    ("vec", _("vector"),),
#    ("wha", _("warehouse"),),
#    ("oth", _("other"),)
)

ORGANIZATION_TRANSPORTTYPE_DEF = (
    ("air", _("air"),),
    ("bot", _("boat"),),
    ("trn", _("train"),),
    ("van", _("van"),),
)

ORGANIZATION_TRANSPORTBY_DEF = (
    ("", "",),                 # None
    ("snd", _("Sender"),),      # mittente
    ("rcp", _("Recipient"),),   # destinatario
    ("vec", _("Vector"),),      # vector
)

ORGANIZATION_CARRIAGE_DEF = (
    ("frw", _("CARRIAGE FORWARD"),),     # PORTO ASSEGNATO
    ("pad", _("CARRIAGE PAID"),),        # PORTO FRANCO
    ("exw", _("EX WORKS"),),             # EX WORKS
    ("pdc", _("CARRIAGE PAID W/CHARGE")) # PORTO FRANCO CON ADDEBITO
)

#: CMS SETTINGS:
ORGANIZATION_CMSPLUGIN_REGISTRATION_FORM_CLASSES = (
    ("jmb.organization.forms.OrganizationRegistrationForm", _("organization registration form"),),
    ("jmb.organization.forms.ContactRegistrationForm", _("contact registration form"),),
    )

ORGANIZATION_CMSPLUGIN_REGISTRATION_FORM_TEMPLATES = (
    ("organization/cms_plugins/registration/organization_registration_form.html", _("organization registration form template"),),
    ("organization/cms_plugins/registration/contact_registration_form.html", _("contact registration form template"),),
    )

ORGANIZATION_CMSPLUGIN_REGISTRATION_EMAIL_REGISTRATION_DONE_TEMPLATES = (
    ("organization/cms_plugins/registration/organization_registration_done_email.html", _("organization registration done email template"),),
    ("organization/cms_plugins/registration/contact_registration_done_email.html", _("contact registration done email template"),),
    )

ORGANIZATION_CMSPLUGIN_REGISTRATION_REGISTRATION_DONE_TEMPLATES = (
    ("organization/cms_plugins/registration/organization_registration_done.html", _("organization registration done template"),),
    ("organization/cms_plugins/registration/contact_registration_done.html", _("contact registration done template"),),
    )

ORGANIZATION_CMSPLUGIN_REGISTRATION_EMAIL_ACTIVATION_DONE_TEMPLATES = (
    ("organization/cms_plugins/registration/organization_activation_done_email.html", _("organization activation done email template"),),
    ("organization/cms_plugins/registration/contact_activation_done_email.html", _("contact activation done email template"),),
    )

ORGANIZATION_CMSPLUGIN_REGISTRATION_ACTIVATION_DONE_TEMPLATES = (
    ("organization/cms_plugins/registration/organization_activation_done.html", _("organization activation done template"),),
    ("organization/cms_plugins/registration/contact_activation_done.html", _("contact activation done template"),),
    )

ORGANIZATION_CMSPLUGIN_LOGIN_FORM_CLASSES = (
    ("jmb.organization.forms.LoginForm", _("login form")),
    )

ORGANIZATION_CMSPLUGIN_LOGIN_FORM_TEMPLATES = (
    ("organization/cms_plugins/registration/column_login_form.html", _("login form column template")),
    ("organization/cms_plugins/registration/central_login_form.html", _("login form central template")),
    )

ORGANIZATION_CMSPLUGIN_LOGOUT_FORM_TEMPLATES = (
    ("organization/cms_plugins/registration/column_logout.html", _("logout column template")),
    ("organization/cms_plugins/registration/central_logout.html", _("logout central template")),
    )

ORGANIZATION_CMSPLUGIN_FORGET_PASSWORD_FORM_CLASSES = (
    ("jmb.organization.forms.PeopleForgetPasswordForm", _("forget password form")),
    )

ORGANIZATION_CMSPLUGIN_FORGET_PASSWORD_FORM_TEMPLATES = (
    ("organization/cms_plugins/registration/column_forget_password_form.html", _("forget password column template")),
    ("organization/cms_plugins/registration/central_forget_password_form.html", _("forget password column template")),
    )

ORGANIZATION_CMSPLUGIN_EMPTY_TEMPLATE = "cms_plugins/dummy.html"


# password recovery
ORGANIZATION_CMSPLUGIN_PASSWORDRECOVERY_FORM_CLASSES = (
    ("jmb.organization.forms.RecoveryPasswordForm", _("recovery password form")),
)

ORGANIZATION_CMSPLUGIN_PASSWORDRECOVERY_FORM_TEMPLATES = (
    ("organization/cms_plugins/recovery_password_form.html", _("recovery password form template")),
)

ORGANIZATION_CMSPLUGIN_PASSWORDRECOVERY_DONE_TEMPLATES = (
    ("organization/cms_plugins/recovery_password_done.html", _("recovery password done template")),
)

ORGANIZATION_CMSPLUGIN_PASSWORDRECOVERY_EMAIL_TEMPLATES = (
    ("organization/cms_plugins/recovery_password_email.html", _("recovery password email template")),
)

# password reset
ORGANIZATION_CMSPLUGIN_PASSWORDRESET_NOTLOGGEDIN_FORM_CLASSES = (
    ("jmb.organization.forms.ResetPasswordForm", _("reset password form (not logged in)")),
)

ORGANIZATION_CMSPLUGIN_PASSWORDRESET_LOGGEDIN_FORM_CLASSES = (
    ("jmb.organization.forms.SetPasswordFormWOldPW", _("reset password form (logged in)")),
)

ORGANIZATION_CMSPLUGIN_PASSWORDRESET_FORM_TEMPLATES = (
    ("organization/cms_plugins/reset_password_form.html", _("reset password form template")),
)

ORGANIZATION_CMSPLUGIN_PASSWORDRESET_DONE_TEMPLATES = (
    ("organization/cms_plugins/reset_password_done.html", _("reset password done template")),
)

ORGANIZATION_CMSPLUGIN_PASSWORDRESET_EMAIL_TEMPLATES = (
    ("organization/cms_plugins/reset_password_email.html", _("reset password done template")),
)

==> jmb.organization-0.3.tar.gz: jmb.organization-0.3/jmb/organization/settings.py <==
# -*- coding: utf-8 -*-
from django.utils.translation import ugettext_lazy as _

#: Configurazione dell'unicità dell'Organization
ORGANIZATION_ORGANIZATION_UNIQUE_TOGETHER = (
    #    FIXME
    #    ("vat_number", "ssn", "organization_type__category"),
    ("vat_number", "ssn", "organization_type"),
)

#: Configurazione dello stile dei campi - stile: 'title', 'upper', 'lower'
ORGANIZATION_ORGANIZATION_NAME_STYLE = 'title'
ORGANIZATION_CONTACT_NAME_STYLE = 'title'

#: Configurazione path foto dei contatti
ORGANIZATION_CONTACT_UPLOAD_PHOTO = "contact_photo"

#: Configurazione choices
ORGANIZATION_ORGANIZATIONTYPE_DEF = (
    ("com", _("owner company"),),
    ("cus", _("customer"),),
    ("sup", _("supplier"),),
    ("vec", _("vector"),),
    #    ("wha", _("warehouse"),),
    #    ("oth", _("other"),)
)

ORGANIZATION_TRANSPORTTYPE_DEF = (
    ("air", _("air"),),
    ("bot", _("boat"),),
    ("trn", _("train"),),
    ("van", _("van"),),
)

ORGANIZATION_TRANSPORTBY_DEF = (
    ("", "",),                 # None
    ("snd", _("Sender"),),      # mittente
    ("rcp", _("Recipient"),),   # destinatario
    ("vec", _("Vector"),),      # vector
)

ORGANIZATION_CARRIAGE_DEF = (
    ("frw", _("CARRIAGE FORWARD"),),     # PORTO ASSEGNATO
    ("pad", _("CARRIAGE PAID"),),        # PORTO FRANCO
    ("exw", _("EX WORKS"),),             # EX WORKS
    ("pdc", _("CARRIAGE PAID W/CHARGE"))  # PORTO FRANCO CON ADDEBITO
)

#: CMS SETTINGS:
ORGANIZATION_CMSPLUGIN_REGISTRATION_FORM_CLASSES = (
    ("jmb.organization.forms.OrganizationRegistrationForm", _("organization registration form"),),
    ("jmb.organization.forms.ContactRegistrationForm", _("contact registration form"),),
)

ORGANIZATION_CMSPLUGIN_REGISTRATION_FORM_TEMPLATES = (
    ("organization/cms_plugins/registration/organization_registration_form.html",
     _("organization registration form template"),),
    ("organization/cms_plugins/registration/contact_registration_form.html",
     _("contact registration form template"),),
)

ORGANIZATION_CMSPLUGIN_REGISTRATION_EMAIL_REGISTRATION_DONE_TEMPLATES = (
    ("organization/cms_plugins/registration/organization_registration_done_email.html",
     _("organization registration done email template"),),
    ("organization/cms_plugins/registration/contact_registration_done_email.html",
     _("contact registration done email template"),),
)

ORGANIZATION_CMSPLUGIN_REGISTRATION_REGISTRATION_DONE_TEMPLATES = (
    ("organization/cms_plugins/registration/organization_registration_done.html",
     _("organization registration done template"),),
    ("organization/cms_plugins/registration/contact_registration_done.html",
     _("contact registration done template"),),
)

ORGANIZATION_CMSPLUGIN_REGISTRATION_EMAIL_ACTIVATION_DONE_TEMPLATES = (
    ("organization/cms_plugins/registration/organization_activation_done_email.html",
     _("organization activation done email template"),),
    ("organization/cms_plugins/registration/contact_activation_done_email.html",
     _("contact activation done email template"),),
)

ORGANIZATION_CMSPLUGIN_REGISTRATION_ACTIVATION_DONE_TEMPLATES = (
    ("organization/cms_plugins/registration/organization_activation_done.html",
     _("organization activation done template"),),
    ("organization/cms_plugins/registration/contact_activation_done.html",
     _("contact activation done template"),),
)

ORGANIZATION_CMSPLUGIN_LOGIN_FORM_CLASSES = (
    ("jmb.organization.forms.LoginForm", _("login form")),
)

ORGANIZATION_CMSPLUGIN_LOGIN_FORM_TEMPLATES = (
    ("organization/cms_plugins/registration/column_login_form.html",
     _("login form column template")),
    ("organization/cms_plugins/registration/central_login_form.html",
     _("login form central template")),
)

ORGANIZATION_CMSPLUGIN_LOGOUT_FORM_TEMPLATES = (
    ("organization/cms_plugins/registration/column_logout.html", _("logout column template")),
    ("organization/cms_plugins/registration/central_logout.html", _("logout central template")),
)

ORGANIZATION_CMSPLUGIN_FORGET_PASSWORD_FORM_CLASSES = (
    ("jmb.organization.forms.PeopleForgetPasswordForm", _("forget password form")),
)

ORGANIZATION_CMSPLUGIN_FORGET_PASSWORD_FORM_TEMPLATES = (
    ("organization/cms_plugins/registration/column_forget_password_form.html",
     _("forget password column template")),
    ("organization/cms_plugins/registration/central_forget_password_form.html",
     _("forget password column template")),
)

ORGANIZATION_CMSPLUGIN_EMPTY_TEMPLATE = "cms_plugins/dummy.html"


# password recovery
ORGANIZATION_CMSPLUGIN_PASSWORDRECOVERY_FORM_CLASSES = (
    ("jmb.organization.forms.RecoveryPasswordForm", _("recovery password form")),
)

ORGANIZATION_CMSPLUGIN_PASSWORDRECOVERY_FORM_TEMPLATES = (
    ("organization/cms_plugins/recovery_password_form.html", _("recovery password form template")),
)

ORGANIZATION_CMSPLUGIN_PASSWORDRECOVERY_DONE_TEMPLATES = (
    ("organization/cms_plugins/recovery_password_done.html", _("recovery password done template")),
)

ORGANIZATION_CMSPLUGIN_PASSWORDRECOVERY_EMAIL_TEMPLATES = (
    ("organization/cms_plugins/recovery_password_email.html",
     _("recovery password email template")),
)

# password reset
ORGANIZATION_CMSPLUGIN_PASSWORDRESET_NOTLOGGEDIN_FORM_CLASSES = (
    ("jmb.organization.forms.ResetPasswordForm", _("reset password form (not logged in)")),
)

ORGANIZATION_CMSPLUGIN_PASSWORDRESET_LOGGEDIN_FORM_CLASSES = (
    ("jmb.organization.forms.SetPasswordFormWOldPW", _("reset password form (logged in)")),
)

ORGANIZATION_CMSPLUGIN_PASSWORDRESET_FORM_TEMPLATES = (
    ("organization/cms_plugins/reset_password_form.html", _("reset password form template")),
)

ORGANIZATION_CMSPLUGIN_PASSWORDRESET_DONE_TEMPLATES = (
    ("organization/cms_plugins/reset_password_done.html", _("reset password done template")),
)

ORGANIZATION_CMSPLUGIN_PASSWORDRESET_EMAIL_TEMPLATES = (
    ("organization/cms_plugins/reset_password_email.html", _("reset password done template")),
)
